argon2_cffi: The secure Argon2 password hashing algorithm
=========================================================

Description
-----------

The secure Argon2 password hashing algorithm.

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/argon2-cffi/

